.. -*- coding: utf-8 -*-

************
Contributing
************

.. toctree::
    :maxdepth: 1

    install_from_sources
    coding_standards_css
    coding_standards_js
    continuous-integration
    features_list
    refactoring-the-css-with-uiprops
